# oocone

[![Tests](https://github.com/sleiner/oocone/workflows/Tests/badge.svg)](https://github.com/sleiner/oocone/actions?query=workflow%3Aci)
[![pypi version](https://img.shields.io/pypi/v/oocone.svg)](https://pypi.org/project/oocone/)
[![Code style: ruff](https://img.shields.io/badge/code%20style-ruff-000000.svg)](https://astral.sh/ruff)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)

Unofficial library for interacting with an enocoo energy management system

## Notable users

-   [ha_enocoo](https://github.com/sleiner/ha_enocoo): enocoo integration for [Home Assistant](https://home-assistant.io)

## Requirements

oocone requires Python >= 3.13.2.
